#!/bin/sh

# save.sh:  create 'release tarball' of ntm-52
#
# To save a new release:
#   ntm-52/save.sh  tarfile_name  dir_name
#     ntm-51/save.sh  51b16         # save ~/ntm-51 to NeTraMet51b16.tar.gz
#     ntm-52/save.sh  NeTraMet cvs  # save ./NeTraMet to cvs.tar.gz

# Parameters:
#   ntm_dir =  Directory to save files from

#   base_dir = Directory name of files within the tar file
#   tar_fn =   Name prefix for the tar file

ntm_dir=~/ntm-52

if [ $# -eq 0 ]; then
   echo No args given, save ~/ntm-52 to NeTraMet.tar.gz
   base_dir='NeTraMet'
else
   if [ $# -eq 1 ]; then
      base_dir="NeTraMet$1"
      tar_fn=$base_dir
   else
      base_dir=$1
      tar_fn=$2
      fi
   fi

echo "save $ntm_dir to $base_dir.tar.gz"

mv $ntm_dir $base_dir

rm $base_dir.tar.gz
rm $base_dir/src/*/*/*~
rm $base_dir/src/*/*~
rm $base_dir/*~
rm $base_dir/#*

tar -cf $tar_fn.tar \
   $base_dir/*in $base_dir/*/*in $base_dir/*/*/*in \
   $base_dir/README $base_dir/*.txt \
   $base_dir/*.sh $base_dir/etc/install-sh \
   $base_dir/etc/config.sub $base_dir/etc/config.guess \
   $base_dir/doc/NeTraMet/*ice $base_dir/doc/NeTraMet/*ory \
   $base_dir/doc/NeTraMet/*.txt $base_dir/doc/NeTraMet/*.html \
   $base_dir/doc/NeTraMet/*.srl $base_dir/doc/NeTraMet/*.rb \
   $base_dir/doc/snmp/HIS* $base_dir/doc/snmp/*.snmp \
   $base_dir/doc/snmp/READ* $base_dir/doc/snmp/exclude \
   $base_dir/doc/snmp/snmp* $base_dir/doc/snmp/var* \
   $base_dir/examples/*.srl $base_dir/examples/non-srl/rules.* \
   $base_dir/lib/*.pm \
   $base_dir/mib/*.txt $base_dir/mib/*.auckland \
   $base_dir/pc/*.txt $base_dir/pc/*.cfg \
   $base_dir/INSTALL $base_dir/configure \
   $base_dir/src/*/README* \
   $base_dir/src/*/*.c $base_dir/src/*/*.cpp $base_dir/src/*/*.h \
   $base_dir/src/bgp/*/*.c $base_dir/src/bgp/*/*.h \
   $base_dir/src/meter/tcpdump/*.h $base_dir/src/meter/tcpdump/net/*.h \
   $base_dir/src/meter/threads/*.h $base_dir/src/meter/threads/*.c \
   $base_dir/src/meter/threads/Makefile

gzip $tar_fn.tar

mv $base_dir $ntm_dir


# $Log: save.sh,v $
# Revision 1.9  2007/01/18 04:11:00  nevil
# Version 5.2: Config files updated to build on Mac OS X (10.4)
#
# Revision 1.6  2006/03/22 16:39:13  nevil
# 51b16:
#    Added config.sub from autoconf259 to etc; ./configure now recognises amd64
#    Fixed bad DNS_RECSZ values; set delta_OK = 0 when ignoring records
#       with payload_len == 0
#    Added nested #defines to trace DNS_RECSZ for TCP or TCP+UDP records
#
# Revision 1.5  2006/03/21 22:20:06  nevil
# Put CVS headers into ntm_conf and Makefile .in
#
# Revision 1.4  2006/03/21 21:48:54  nevil
# Generalise save.sh using command-line arguments
#
# Revision 1.3  2006/03/21 20:39:13  nevil
# another test
#
